export const ANSI_PREFIX = '\x1b[';

function esc(pieces: TemplateStringsArray): string {
	return ANSI_PREFIX + pieces[0];
}

/**
 * ANSI escapes for various inputs
 */
export enum KeyCommand {
	ArrowUp = `${ANSI_PREFIX}A`,
	ArrowDown = `${ANSI_PREFIX}B`,
	ArrowRight = `${ANSI_PREFIX}C`,
	ArrowLeft = `${ANSI_PREFIX}D`,
}

export const Ansi = {
	ClearLine: esc`K`,
	ClearScreen: esc`2J`,
	ResetCursor: esc`H`,
	HideCursor: esc`?25l`,
	ShowCursor: esc`?25h`,
	GetCursorLocation: esc`6n`,
	moveCursor: function moveCursor(row: number, col: number): string {
		// Convert to 1-based counting
		row++;
		col++;

		return `\x1b[${row};${col}H`;
	},
	moveCursorForward: (col: number): string => `${ANSI_PREFIX}${col}C`,
	moveCursorDown: (row: number): string => `${ANSI_PREFIX}${row}B`,
};

export default Ansi;
